@@ -13,6 +13,7 @@ from motorcortex.subscribe import Subscribe
 from motorcortex.subscription import Subscription
 from motorcortex.motorcortex_pb2 import *
 
+
 def statusToStr(motorcortex_msg, code):
     """Converts status codes to a readable message.
 
@@ -31,7 +32,7 @@ def statusToStr(motorcortex_msg, code):
 
     """
 
-    status = ''
+    status = 'Unknown code'
     if code == motorcortex_msg.OK:
         status = 'Success'
     elif code == motorcortex_msg.FAILED:
@@ -54,9 +55,43 @@ def statusToStr(motorcortex_msg, code):
         status = 'Operation is not permitted, user is not logged in'
     elif code == motorcortex_msg.PERMISSION_DENIED:
         status = 'Operation is not permitted, user has no rights'
-    else:
-        status = 'Unknown code'
 
     status += str(' (%s)' % hex(code))
 
     return status
+
+
+def parseUrl(url):
+    end = url.rfind(':')
+    start = url.rfind(':', 0, end)
+    req_port = int(url[start + 1:end])
+    sub_port = int(url[end + 1:])
+    address = url[:start]
+    return address, req_port, sub_port
+
+
+def connect(url, motorcortex_types, param_tree, **kwargs):
+    # Parse address
+    address, req_port, sub_port = parseUrl(url)
+    # Open request connection
+    req = Request(motorcortex_types, param_tree)
+    if not req.connect("%s:%s" % (address, req_port), **kwargs).get():
+        raise RuntimeError("Failed to establish request connection")
+    # Open subscribe connection
+    sub = Subscribe(req, motorcortex_types)
+    if not sub.connect("%s:%s" % (address, sub_port), **kwargs).get():
+        raise RuntimeError("Failed to establish subscribe connection")
+    # Login
+    login_reply = req.login(kwargs['login'], kwargs['password'])
+    login_reply_msg = login_reply.get()
+
+    motorcortex_msg = motorcortex_types.motorcortex()
+    if login_reply_msg.status == motorcortex_msg.OK:
+        raise RuntimeError("Login failed, status: %s" % login_reply_msg.status)
+
+    # Requesting a parameter tree
+    param_tree_reply = req.getParameterTree()
+    tree = param_tree_reply.get()
+    param_tree.load(tree)
+
+    return req, sub
